@@ -7,7 +7,7 @@ use crate::{
     strings, ui,
 };
 use asyncgit::{sync, CWD};
-use crossterm::event::{Event, KeyCode, KeyModifiers};
+use crossterm::event::{Event, KeyCode};
 use log::error;
 use std::borrow::Cow;
 use strings::commands;
@@ -76,17 +76,11 @@ impl Component for CommitComponent {
     fn event(&mut self, ev: Event) -> bool {
         if self.visible {
             if let Event::Key(e) = ev {
-                let has_ctrl =
-                    e.modifiers.contains(KeyModifiers::CONTROL);
                 match e.code {
                     KeyCode::Esc => {
                         self.hide();
                     }
                     KeyCode::Char(c) => {
-                        // ignore and early out on ctrl+c
-                        if c == 'c' && has_ctrl {
-                            return false;
-                        }
                         self.msg.push(c);
                     }
                     KeyCode::Enter if self.can_commit() => {
@@ -128,7 +122,7 @@ impl CommitComponent {
 
     fn commit(&mut self) {
         if let HookResult::NotOk(e) =
-            sync::hooks_commit_msg(CWD, &mut self.msg)
+            sync::hooks_commit_msg(CWD, &mut self.msg).unwrap()
         {
             error!("commit-msg hook error: {}", e);
             self.queue.borrow_mut().push_back(
@@ -141,7 +135,9 @@ impl CommitComponent {
         }
 
         sync::commit(CWD, &self.msg).unwrap();
-        if let HookResult::NotOk(e) = sync::hooks_post_commit(CWD) {
+        if let HookResult::NotOk(e) =
+            sync::hooks_post_commit(CWD).unwrap()
+        {
             error!("post-commit hook error: {}", e);
             self.queue.borrow_mut().push_back(
                 InternalEvent::ShowMsg(format!(
