@@ -19,12 +19,46 @@ pub use help::HelpComponent;
 pub use msg::MsgComponent;
 pub use reset::ResetComponent;
 
+/// allows generating code to make sure
+/// we always enumerate all components in both getter functions
+#[macro_export]
+macro_rules! accessors {
+    ($self:ident, [$($element:ident),+]) => {
+        fn components(& $self) -> Vec<&dyn Component> {
+            vec![
+                $(&$self.$element,)+
+            ]
+        }
+
+        fn components_mut(&mut $self) -> Vec<&mut dyn Component> {
+            vec![
+                $(&mut $self.$element,)+
+            ]
+        }
+    };
+}
+
+pub fn event_pump(
+    ev: Event,
+    components: &mut [&mut dyn Component],
+) -> bool {
+    for c in components {
+        if c.event(ev) {
+            return true;
+        }
+    }
+
+    false
+}
+
 #[derive(Copy, Clone)]
 pub enum ScrollType {
     Up,
     Down,
     Home,
     End,
+    PageUp,
+    PageDown,
 }
 
 ///
@@ -48,7 +82,7 @@ pub fn visibility_blocking<T: Component>(
 ///
 pub trait DrawableComponent {
     ///
-    fn draw<B: Backend>(&self, f: &mut Frame<B>, rect: Rect);
+    fn draw<B: Backend>(&mut self, f: &mut Frame<B>, rect: Rect);
 }
 
 /// base component trait
