@@ -1,5 +1,5 @@
 mod revlog;
-
-//TODO: tab traits?
+mod status;
 
 pub use revlog::Revlog;
+pub use status::Status;
